<?php

namespace Litecms\Blogmanagement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Blogmanagement\Models\Blogmanagement;

class BlogmanagementPolicy
{

    /**
     * Determine if the given user can view the blogmanagement.
     *
     * @param UserPolicy $user
     * @param Blogmanagement $blogmanagement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Blogmanagement $blogmanagement)
    {
        if ($user->canDo('blogmanagement.blogmanagement.view') && $user->isAdmin()) {
            return true;
        }

        return $blogmanagement->user_id == user_id() && $blogmanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a blogmanagement.
     *
     * @param UserPolicy $user
     * @param Blogmanagement $blogmanagement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blogmanagement.blogmanagement.create');
    }

    /**
     * Determine if the given user can update the given blogmanagement.
     *
     * @param UserPolicy $user
     * @param Blogmanagement $blogmanagement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Blogmanagement $blogmanagement)
    {
        if ($user->canDo('blogmanagement.blogmanagement.edit') && $user->isAdmin()) {
            return true;
        }

        return $blogmanagement->user_id == user_id() && $blogmanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given blogmanagement.
     *
     * @param UserPolicy $user
     * @param Blogmanagement $blogmanagement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Blogmanagement $blogmanagement)
    {
        return $blogmanagement->user_id == user_id() && $blogmanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given blogmanagement.
     *
     * @param UserPolicy $user
     * @param Blogmanagement $blogmanagement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Blogmanagement $blogmanagement)
    {
        if ($user->canDo('blogmanagement.blogmanagement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given blogmanagement.
     *
     * @param UserPolicy $user
     * @param Blogmanagement $blogmanagement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Blogmanagement $blogmanagement)
    {
        if ($user->canDo('blogmanagement.blogmanagement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
